@@ -2102,6 +2102,12 @@ void KstApp::updateDataNotifier() {
 
 
 void KstApp::updateDataDialogs(bool dm, bool vm) {
+
+  ViewScalarsDialogAction->setEnabled(viewScalarsDialog->hasContent());
+  ViewVectorsDialogAction->setEnabled(viewVectorsDialog->hasContent());
+  ViewMatricesDialogAction->setEnabled(viewMatricesDialog->hasContent());
+  ViewFitsDialogAction->setEnabled(viewFitsDialog->hasContent());
+
   if (!viewScalarsDialog->isHidden()) {
     viewScalarsDialog->updateViewScalarsDialog();
   }
