@@ -381,8 +381,10 @@ bool KstDoc::openDocument(const KURL& url, const QString& o_file,
         KST::addVectorToList(KstVectorPtr(avector));
       } else if (e.tagName() == "plugin") {
         KstDataObjectPtr p = new KstPlugin(e);
-        KstWriteLocker dowl(&KST::dataObjectList.lock());
-        KST::dataObjectList.append(p);
+        if (p->isValid()) {
+          KstWriteLocker dowl(&KST::dataObjectList.lock());
+          KST::dataObjectList.append(p);
+        }
       } else if (e.tagName() == "curve") {
         KstDataObjectPtr p = new KstVCurve(e);
         KstWriteLocker dowl(&KST::dataObjectList.lock());
@@ -792,14 +794,25 @@ void KstDoc::deleteContents() {
     }
   }
 
-  KST::vectorList.lock().writeLock();
-  KST::vectorList.clear();
-  KST::vectorList.lock().unlock();
-  
+  KST::dataObjectList.lock().writeLock();
+  // Avoid deadlock in DataObject destructor
+  KstDataObjectList tmpDol = QDeepCopy<KstDataObjectList>(KST::dataObjectList);
+  KST::dataObjectList.clear();
+  KST::dataObjectList.lock().unlock();
+  tmpDol.clear();
+
+  KST::dataSourceList.lock().writeLock();
+  KST::dataSourceList.clear();
+  KST::dataSourceList.lock().unlock();
+
   KST::matrixList.lock().writeLock();
   KST::matrixList.clear();
   KST::matrixList.lock().unlock();
 
+  KST::vectorList.lock().writeLock();
+  KST::vectorList.clear();
+  KST::vectorList.lock().unlock();
+  
   KST::scalarList.lock().writeLock();
   KST::scalarList.clear();
   KST::scalarList.lock().unlock();
@@ -808,14 +821,6 @@ void KstDoc::deleteContents() {
   KST::stringList.clear();
   KST::stringList.lock().unlock();
 
-  KST::dataSourceList.lock().writeLock();
-  KST::dataSourceList.clear();
-  KST::dataSourceList.lock().unlock();
-
-  KST::dataObjectList.lock().writeLock();
-  KST::dataObjectList.clear();
-  KST::dataObjectList.lock().unlock();
-
   emit updateDialogs();
 }
 
