@@ -280,7 +280,6 @@ bool KstImageDialogI::editSingleObject(KstImagePtr imPtr) {
     double lowerZDouble, upperZDouble;
     if (!checkParameters(lowerZDouble, upperZDouble)) {
       KMessageBox::sorry(this, i18n("Image type was changed: Lower Z threshold cannot be higher than Upper Z threshold."));
-      pMatrix->unlock();
       imPtr->unlock();
       return false;
     }
@@ -356,7 +355,6 @@ bool KstImageDialogI::editSingleObject(KstImagePtr imPtr) {
     if (imPtr->hasColorMap()) {
       if (pLowerZ > pUpperZ) {
         KMessageBox::sorry(this, i18n("The Lower Z threshold cannot be higher than Upper Z threshold."));
-        pMatrix->unlock();
         imPtr->unlock();
         return false;
       }
@@ -550,7 +548,7 @@ bool KstImageDialogI::checkParameters(double& lowerZDouble, double& upperZDouble
       KMessageBox::sorry(this, i18n("The upper and lower thresholds are not valid.  Enter valid decimal numbers for the thresholds."));
       return false;
     }
-    if (lowerZDouble > upperZDouble) {
+    if (lowerZDouble >= upperZDouble) {
       KMessageBox::sorry(this, i18n("The lower threshold cannot be greater than the upper threshold."));
       return false;
     }
