@@ -497,6 +497,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           plugin->outputVectors().insert((*it)._name, v);
           KST::addVectorToList(v);
         }
+        v->setTagName(nt);
       } else if (plugin->outputVectors()[(*it)._name]->tagName() != nt) {
         while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
@@ -510,6 +511,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           plugin->outputVectors().insert((*it)._name, v);
           KST::addVectorToList(v);
         }
+        v->setTagName(nt);
       }
     } else if ((*it)._type == Plugin::Data::IOValue::StringType) {
       if (!KstData::self()->vectorTagNameNotUnique(nt, false)) {
@@ -521,6 +523,8 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           s->writeLock();
           plugin->outputStrings().insert((*it)._name, s);
         }
+        s->setTagName(nt);
+
       } else if (plugin->outputStrings()[(*it)._name]->tagName() != nt) {
         while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
@@ -533,6 +537,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           s->writeLock();
           plugin->outputStrings().insert((*it)._name, s);
         }
+        s->setTagName(nt);
       }
     } else if ((*it)._type == Plugin::Data::IOValue::PidType) {
       // Nothing
@@ -546,6 +551,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           s->writeLock();
           plugin->outputScalars().insert((*it)._name, s);
         }
+        s->setTagName(nt);
       } else if (plugin->outputScalars()[(*it)._name]->tagName() != nt) {
         while (KstData::self()->vectorTagNameNotUnique(nt, false)) {
           nt += "'";
@@ -558,6 +564,7 @@ bool KstPluginDialogI::saveOutputs(KstPluginPtr plugin, KstSharedPtr<Plugin> p)
           s->writeLock();
           plugin->outputScalars().insert((*it)._name, s);
         }
+        s->setTagName(nt);
       }
     }
   }
