@@ -36,12 +36,14 @@
 KstDataObject::KstDataObject() : KstObject() {
   //kstdDebug() << "+++ CREATING DATA OBJECT: " << (void*)this << endl;
   _curveHints = new KstCurveHintList;
+  _isInputLoaded = false;
 }
 
 KstDataObject::KstDataObject(const QDomElement& e) : KstObject() {
   Q_UNUSED(e)
   //kstdDebug() << "+++ CREATING DATA OBJECT: " << (void*)this << endl;
   _curveHints = new KstCurveHintList;
+  _isInputLoaded = false;
 }
 
 
@@ -159,6 +161,7 @@ bool KstDataObject::loadInputs() {
   
   setDirty();
 
+  _isInputLoaded = true;
   return rc;
 }
 
