@@ -211,7 +211,7 @@ KstObject::UpdateType KstEquation::update(int update_counter) {
   Equation::Context ctx;
   ctx.sampleCount = _ns;
   ctx.xVector = v;
-  usedUpdated = KstObject::UPDATE == _pe->update(update_counter, &ctx);
+  usedUpdated = _pe && KstObject::UPDATE == _pe->update(update_counter, &ctx);
 
   KstObject::UpdateType rc = NO_CHANGE; // if force, rc = UPDATE anyway.
   if (force || xUpdated || usedUpdated) {
@@ -267,11 +267,10 @@ void KstEquation::setEquation(const QString& in_fn) {
   // document loading with vector lazy-loading
   setDirty();
   _equation = in_fn;
+
   VectorsUsed.clear();
-  for (KstScalarMap::Iterator i = _inputScalars.begin(); i != _inputScalars.end(); ++i) {
-    (*i)->unlock();
-  }
-  _inputScalars.clear();
+  ScalarsUsed.clear();
+
   _ns = 2; // reset the updating
   delete _pe;
   _pe = 0L;
@@ -288,11 +287,16 @@ void KstEquation::setEquation(const QString& in_fn) {
       ctx.xVector = *_xInVector;
       Equation::FoldVisitor vis(&ctx, &_pe);
       KstStringMap sm;
-      _pe->collectObjects(VectorsUsed, _inputScalars, sm);
-      for (KstScalarMap::Iterator i = _inputScalars.begin(); i != _inputScalars.end(); ++i) {
-        (*i)->readLock();
+
+      if (_pe->collectObjects(VectorsUsed, ScalarsUsed, sm)) {
+        _pe->update(-1, &ctx);
+      } else {
+        //we have bad objects...
+        KstDebug::self()->log(i18n("Equation [%1] references non-existent objects.").arg(_equation), KstDebug::Error);
+        delete (Equation::Node*)ParsedEquation;
+        ParsedEquation = 0L;
+        Equation::mutex().unlock();
       }
-      _pe->update(-1, &ctx);
     } else {
       // Parse error
       KstDebug::self()->log(i18n("Equation [%1] failed to parse.  Errors follow.").arg(_equation), KstDebug::Warning);
@@ -301,6 +305,7 @@ void KstEquation::setEquation(const QString& in_fn) {
       }
       delete (Equation::Node*)ParsedEquation;
       ParsedEquation = 0L;
+      _pe = 0L;
       Equation::mutex().unlock();
     }
   }
@@ -439,11 +444,12 @@ bool KstEquation::FillY(bool force) {
     if (_pe && rc == 0) {
       Equation::FoldVisitor vis(&ctx, &_pe);
       KstStringMap sm;
-      _pe->collectObjects(VectorsUsed, _inputScalars, sm);
+      _pe->collectObjects(VectorsUsed, ScalarsUsed, sm);
       ParsedEquation = 0L;
     } else {
       delete (Equation::Node*)ParsedEquation;
       ParsedEquation = 0L;
+      _pe = 0L;
       return false;
     }
   }
