@@ -38,6 +38,7 @@ KstPlugin::KstPlugin()
   _inStringCnt = 0;
   _outStringCnt = 0;
   commonConstructor();
+  _isInputLoaded = true;
 }
 
 
@@ -426,9 +427,13 @@ KstObject::UpdateType KstPlugin::update(int update_counter) {
 
 QString KstPlugin::label(int precision) const {
   QString label;
-  
+ 
+  if (!plugin()) {
+    return label;
+  }
+
   label = i18n("%1: %2").arg(plugin()->data()._readableName).arg(tagName());
-  if ((outputVectors())["Parameters"]) {
+  if (outputVectors()["Parameters"]) {
     QString strParamName;
     QString strValue;
     int length = (outputVectors())["Parameters"]->length();
@@ -501,10 +506,17 @@ bool KstPlugin::slaveVectorsUsed() const {
 
 
 bool KstPlugin::isValid() const {
-  return _inputVectors.count() == _inArrayCnt &&
-         _inputScalars.count() == _inScalarCnt - _inPid &&
-         _inputStrings.count() == _inStringCnt &&
-         _plugin.data() != 0L;
+  if (_isInputLoaded) {
+    return _inputVectors.count() == _inArrayCnt &&
+           _inputScalars.count() == _inScalarCnt - _inPid &&
+           _inputStrings.count() == _inStringCnt &&
+           _plugin.data() != 0L;
+  } else {
+    return _inputVectorLoadQueue.count() == _inArrayCnt &&
+           _inputScalarLoadQueue.count() == _inScalarCnt - _inPid &&
+           _inputStringLoadQueue.count() == _inStringCnt &&
+           _plugin.data() != 0L;
+  }
 }
 
 
