@@ -1045,6 +1045,10 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
                     minY = Ly;
                   }
                   if (KDE_ISUNLIKELY(minY >= Ly && minY <= Hy && maxY >= Ly && maxY <= Hy)) {
+                    if (index > 0) {
+                      p->drawPolyline(points, 0, index);
+                      index = 0;
+                    }
                     p->drawLine(X2i, d2i(minY), X2i, d2i(maxY));
                   }
                 }
