@@ -318,12 +318,12 @@ int main(int argc, char **argv) {
   test("257|-1", 0.0, -1);
 
   // Scalars
-  new KstScalar("test1", 1.0, true);
-  new KstScalar("test2", 0.0, true);
-  new KstScalar("test3", -1.0, true);
-  new KstScalar("test4", NOPOINT, true);
-  new KstScalar("test5", INF, true);
-  new KstScalar("test6", -INF, true);
+  new KstScalar("test1", 0L, 1.0, true);
+  new KstScalar("test2", 0L, 0.0, true);
+  new KstScalar("test3", 0L, -1.0, true);
+  new KstScalar("test4", 0L, NOPOINT, true);
+  new KstScalar("test5", 0L, INF, true);
+  new KstScalar("test6", 0L, -INF, true);
 
   test("[test1]", 0.0, 1.0);
   test("[test4]", 0.0, NOPOINT);
